Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(241)

Unified Diff: chrome/browser/automation/automation_provider_observers.h

Issue 11867023: content: remove NOTIFICATION_SAVE_PACKAGE_SUCCESSFULLY_FINISHED (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/automation/automation_provider_observers.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/automation/automation_provider_observers.h
diff --git a/chrome/browser/automation/automation_provider_observers.h b/chrome/browser/automation/automation_provider_observers.h
index 6ba85aef6083ff29b597aa763306702e02dd4fdd..fec988a58d24942472fdf3add93bf04f88c5f824 100644
--- a/chrome/browser/automation/automation_provider_observers.h
+++ b/chrome/browser/automation/automation_provider_observers.h
@@ -1246,20 +1246,21 @@ class OmniboxAcceptNotificationObserver : public content::NotificationObserver {
};
// Allows the automation provider to wait for a save package notification.
-class SavePackageNotificationObserver : public content::NotificationObserver {
+class SavePackageNotificationObserver
+: public content::DownloadManager::Observer {
public:
SavePackageNotificationObserver(content::DownloadManager* download_manager,
AutomationProvider* automation,
IPC::Message* reply_message);
virtual ~SavePackageNotificationObserver();
- // Overridden from content::NotificationObserver:
- virtual void Observe(int type,
- const content::NotificationSource& source,
- const content::NotificationDetails& details) OVERRIDE;
+ // Overridden from content::DownloadManager::Observer:
+ virtual void OnSavePackageSuccessfullyFinished(
+ content::DownloadManager* manager, content::DownloadItem* item) OVERRIDE;
+ virtual void ManagerGoingDown(content::DownloadManager* manager) OVERRIDE;
private:
- content::NotificationRegistrar registrar_;
+ content::DownloadManager* download_manager_;
base::WeakPtr<AutomationProvider> automation_;
scoped_ptr<IPC::Message> reply_message_;
« no previous file with comments | « no previous file | chrome/browser/automation/automation_provider_observers.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698